@@ -8,3 +8,9 @@ MATCH.timeDate <- function(x, table, nomatch = NA, ...) {
   stopifnot(require("timeDate"))
   match(as.POSIXct(x), as.POSIXct(table), nomatch = nomatch, ...)
 }
+
+MATCH.times <- function(x, table, nomatch = NA, units = "sec", 
+	eps = 1e-10, ...) {
+ match(trunc(x, units, eps), trunc(table, units, eps), nomatch = nomatch, ...)
+}
+
